%define anolis_release 1
%global _hardened_build 1

Summary: WPA/WPA2/IEEE 802.1X Supplicant
Name: wpa_supplicant
Epoch: 1
Version: 2.11
Release: %{anolis_release}%{?dist}
License: BSD
Source0: http://w1.fi/releases/%{name}-%{version}.tar.gz
Source1: wpa_supplicant.conf
Source2: wpa_supplicant.service
Source3: wpa_supplicant.sysconfig
Source4: wpa_supplicant.logrotate

# Distro specific customization and not suitable for upstream,
# Specific updates to defconfig
Patch0: wpa_supplicant-defconfig-keep-options-we-ve-traditionally-used-enab.patch
# Works around busted drivers
Patch1: wpa_supplicant-assoc-timeout.patch
# Ensures that debug output gets flushed immediately to help diagnose driver
# bugs, not suitable for upstream
Patch2: wpa_supplicant-flush-debug-output.patch
# Quiet an annoying and frequent syslog message
Patch3: wpa_supplicant-quiet-scan-results-message.patch
# Distro specific customization for Qt4 build tools, not suitable for upstream
Patch4: wpa_supplicant-gui-qt4.patch
# We keep WEP enabled for now to avoid breaking user setups
Patch6: wpa_supplicant-defconfig-keep-CONFIG_WEP-enabled.patch
# FIXME: Explain why are these two here
Patch7: wpa_supplicant-defconfig-enable-WPA-EAP-SUITE-B-192-ciphers.patch
Patch8: wpa_supplicant-defconfig-enable-OCV-support.patch
# Allow legacy renegotiation with openssl 3.0 to fix connection to
# PEAP/Radius servers that don't support secure renegotiation:
# https://bugzilla.redhat.com/show_bug.cgi?id=2072070
# From James Ralston in comment #24, thanks to James
Patch9: wpa_supplicant-allow-legacy-renegotiation.patch
# Add WPA3 support for Broadcom device
# https://bugzilla.redhat.com/show_bug.cgi?id=2226569
#Patch10: wpa_supplicant-nl80211-check-sae-authentication-offload-support.patch
#Patch11: wpa_supplicant-sae-pass-sae-password-on-connect-for-sae-authentication-offload-support.patch
# Enable IPv6 (#2095296)
Patch12: wpa_supplicant-defconfig-enable-ipv6.patch

# support macsec HW offload
#Patch13: wpa_supplicant-MACsec-Support-GCM-AES-256-cipher-suite.patch
#Patch14: wpa_supplicant-macsec_linux-Support-cipher-suite-configuration.patch
#Patch15: wpa_supplicant-mka-Allow-configuration-of-MACsec-hardware-offload.patch
#Patch16: wpa_supplicant-macsec_linux-Add-support-for-MACsec-hardware-offload.patch

# fix PEAP client to require successful Phase2 authentication when needed (CVE-2023-52160)
#Patch17: wpa_supplicant-PEAP-client-Update-Phase-2-authentication-requiremen.patch

URL: http://w1.fi/wpa_supplicant/

BuildRequires: openssl-devel
BuildRequires: readline-devel
BuildRequires: dbus-devel
BuildRequires: libnl3-devel
BuildRequires: systemd-units
BuildRequires: docbook-utils
BuildRequires: gcc
Requires(post): systemd-sysv
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with support
for WPA and WPA2 (IEEE 802.11i / RSN). Supplicant is the IEEE 802.1X/WPA
component that is used in the client stations. It implements key negotiation
with a WPA Authenticator and it controls the roaming and IEEE 802.11
authentication/association of the wlan driver.

%package doc
Summary: Doc files for wpa_supplicant
Requires: %{name} = %{EVR}
BuildArch: noarch

%description doc
Doc files for wpa_supplicant

%prep
%autosetup -p1 -n %{name}-%{version}


%build
pushd wpa_supplicant
  cp defconfig .config
  export CFLAGS="${CFLAGS:-%optflags} -fPIE -DPIE"
  export CXXFLAGS="${CXXFLAGS:-%optflags} -fPIE -DPIE"
  export LDFLAGS="${LDFLAGS:-%optflags} -pie -Wl,-z,now"
  # yes, BINDIR=_sbindir
  export BINDIR="%{_sbindir}"
  export LIBDIR="%{_libdir}"
  make %{_smp_mflags} V=1
  make eapol_test V=1
  make -C doc/docbook man V=1
  rm doc/docbook/wpa_gui.8
popd


%install
# config
install -D -m 0600 %{SOURCE1} %{buildroot}/%{_sysconfdir}/wpa_supplicant/wpa_supplicant.conf

# init scripts
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/wpa_supplicant.service
install -D -m 0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/wpa_supplicant
install -D -m 0644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/logrotate.d/wpa_supplicant

# binary
install -d %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/wpa_passphrase %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/wpa_cli %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/wpa_supplicant %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/eapol_test %{buildroot}/%{_sbindir}
install -D -m 0644 wpa_supplicant/dbus/dbus-wpa_supplicant.conf \
  %{buildroot}/%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
install -D -m 0644 wpa_supplicant/dbus/fi.w1.wpa_supplicant1.service \
  %{buildroot}/%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service

# man pages
install -d %{buildroot}%{_mandir}/man{5,8}
install -m 0644 wpa_supplicant/doc/docbook/*.8 %{buildroot}%{_mandir}/man8
install -m 0644 wpa_supplicant/doc/docbook/*.5 %{buildroot}%{_mandir}/man5

# some cleanup in docs and examples
rm -f  wpa_supplicant/doc/.cvsignore
rm -rf wpa_supplicant/doc/docbook
chmod -R 0644 wpa_supplicant/examples/*.py


%post
%systemd_post wpa_supplicant.service


%preun
%systemd_preun wpa_supplicant.service

%triggerun -- wpa_supplicant < 0.7.3
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply wpa_supplicant
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save wpa_supplicant >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del wpa_supplicant >/dev/null 2>&1 || :
/bin/systemctl try-restart wpa_supplicant.service >/dev/null 2>&1 || :


%files
%config(noreplace) %{_sysconfdir}/wpa_supplicant/wpa_supplicant.conf
%config(noreplace) %{_sysconfdir}/sysconfig/wpa_supplicant
%dir %{_sysconfdir}/logrotate.d
%config(noreplace) %{_sysconfdir}/logrotate.d/wpa_supplicant
%{_unitdir}/wpa_supplicant.service
%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service
%{_sbindir}/wpa_passphrase
%{_sbindir}/wpa_supplicant
%{_sbindir}/wpa_cli
%{_sbindir}/eapol_test
%dir %{_sysconfdir}/wpa_supplicant
%{_mandir}/man8/wpa_supplicant.8.*
%{_mandir}/man8/wpa_priv.8.*
%{_mandir}/man8/wpa_passphrase.8.*
%{_mandir}/man8/wpa_cli.8.*
%{_mandir}/man8/wpa_background.8.*
%{_mandir}/man8/eapol_test.8.*
%{_mandir}/man5/*
%doc wpa_supplicant/eap_testing.txt
%doc wpa_supplicant/wpa_supplicant.conf
%doc wpa_supplicant/examples
%license COPYING

%files doc
%doc README
%doc wpa_supplicant/ChangeLog
%doc wpa_supplicant/todo.txt

%changelog
* Fri Dec 06 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:2.11-1
- update to 2.11 fix CVE-2023-52424

* Tue Feb 20 2024 Funda Wang <fundawang@yeah.net> - 1:2.10-4
- Add some patches from other distro

* Fri Dec 16 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:2.10-3
- fix wrong requires of doc

* Tue Sep 06 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:2.10-2
- seperate doc sub packages

* Fri Apr 15 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:2.10-1
- init from upstream
